pub enum SystemStage {
Startup,
AssetSync,
AssetSyncDeps,
PreUpdate,
Update,
PostUpdate,
PreRender,
Render,
PostRender,
}Expand description
Determines when during a frame a system is executed.
Startup runs on every tick until a system on it
returns Some(()) (then never again). Systems returning Option<()> are
automatically “once” — they retry each tick until they succeed.
Variants
Startup
Run-once startup systems — any system added here that returns
Option<()> runs until it returns Some(()), then is permanently
retired.
AssetSync
Upload CPU-side source assets to the GPU backend.
AssetSyncDeps
Construct GPU resources and upload assets that depend on other processed assets.
PreUpdate
Before the main update.
Update
Main game-logic update.
PostUpdate
After the main update.
PreRender
Prepare rendering data and poll for the GPU backend.
Render
Issue draw calls.
PostRender
Cleanup or post-processing after rendering.