Module assets

Module assets 

Modules

deps
handle
plugin
required
singleton_asset
Lazy resources — singleton GPU resources that are constructed once, on-demand, as soon as their backend and dependencies become available, but (unlike [Asset]) are never tracked by a [Handle] or stored in a pool, because there is only ever one of them.
storage
upload