pub struct RawAssetHandle(/* private fields */);Trait Implementations
Sourceimpl Clone for RawAssetHandle
impl Clone for RawAssetHandle
Sourcefn clone(&self) -> RawAssetHandle
fn clone(&self) -> RawAssetHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RawAssetHandle
Sourceimpl Debug for RawAssetHandle
impl Debug for RawAssetHandle
Sourceimpl Default for RawAssetHandle
impl Default for RawAssetHandle
Sourcefn default() -> RawAssetHandle
fn default() -> RawAssetHandle
Returns the “default value” for a type. Read more
impl Eq for RawAssetHandle
Sourceimpl From<KeyData> for RawAssetHandle
impl From<KeyData> for RawAssetHandle
Sourceimpl Hash for RawAssetHandle
impl Hash for RawAssetHandle
Sourceimpl Key for RawAssetHandle
impl Key for RawAssetHandle
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for RawAssetHandle
impl Ord for RawAssetHandle
Sourcefn cmp(&self, other: &RawAssetHandle) -> Ordering
fn cmp(&self, other: &RawAssetHandle) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RawAssetHandle
impl PartialEq for RawAssetHandle
Sourcefn eq(&self, other: &RawAssetHandle) -> bool
fn eq(&self, other: &RawAssetHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for RawAssetHandle
impl PartialOrd for RawAssetHandle
impl StructuralPartialEq for RawAssetHandle