pub struct FunctionSystem<F, Marker, State = ()> {
pub func: F,
/* private fields */
}Fields
func: FTrait Implementations
Sourceimpl<T, A, B> System for FunctionSystem<T, (A, B), (A::State, B::State)>where
T: FnMut(A, B) + for<'a> FnMut(A::Item<'a>, B::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
impl<T, A, B> System for FunctionSystem<T, (A, B), (A::State, B::State)>where
T: FnMut(A, B) + for<'a> FnMut(A::Item<'a>, B::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
Sourceimpl<T, A, B, C> System for FunctionSystem<T, (A, B, C), (A::State, B::State, C::State)>where
T: FnMut(A, B, C) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
impl<T, A, B, C> System for FunctionSystem<T, (A, B, C), (A::State, B::State, C::State)>where
T: FnMut(A, B, C) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
Sourceimpl<T, A, B, C, D> System for FunctionSystem<T, (A, B, C, D), (A::State, B::State, C::State, D::State)>where
T: FnMut(A, B, C, D) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
impl<T, A, B, C, D> System for FunctionSystem<T, (A, B, C, D), (A::State, B::State, C::State, D::State)>where
T: FnMut(A, B, C, D) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E> System for FunctionSystem<T, (A, B, C, D, E), (A::State, B::State, C::State, D::State, E::State)>where
T: FnMut(A, B, C, D, E) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
impl<T, A, B, C, D, E> System for FunctionSystem<T, (A, B, C, D, E), (A::State, B::State, C::State, D::State, E::State)>where
T: FnMut(A, B, C, D, E) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F> System for FunctionSystem<T, (A, B, C, D, E, F), (A::State, B::State, C::State, D::State, E::State, F::State)>where
T: FnMut(A, B, C, D, E, F) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
impl<T, A, B, C, D, E, F> System for FunctionSystem<T, (A, B, C, D, E, F), (A::State, B::State, C::State, D::State, E::State, F::State)>where
T: FnMut(A, B, C, D, E, F) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F, G> System for FunctionSystem<T, (A, B, C, D, E, F, G), (A::State, B::State, C::State, D::State, E::State, F::State, G::State)>where
T: FnMut(A, B, C, D, E, F, G) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
impl<T, A, B, C, D, E, F, G> System for FunctionSystem<T, (A, B, C, D, E, F, G), (A::State, B::State, C::State, D::State, E::State, F::State, G::State)>where
T: FnMut(A, B, C, D, E, F, G) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F, G, H> System for FunctionSystem<T, (A, B, C, D, E, F, G, H), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State)>where
T: FnMut(A, B, C, D, E, F, G, H) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
impl<T, A, B, C, D, E, F, G, H> System for FunctionSystem<T, (A, B, C, D, E, F, G, H), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State)>where
T: FnMut(A, B, C, D, E, F, G, H) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F, G, H, I> System for FunctionSystem<T, (A, B, C, D, E, F, G, H, I), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State, I::State)>where
T: FnMut(A, B, C, D, E, F, G, H, I) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>, I::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
I: SystemParam + 'static,
impl<T, A, B, C, D, E, F, G, H, I> System for FunctionSystem<T, (A, B, C, D, E, F, G, H, I), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State, I::State)>where
T: FnMut(A, B, C, D, E, F, G, H, I) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>, I::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
I: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F, G, H, I, J> System for FunctionSystem<T, (A, B, C, D, E, F, G, H, I, J), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State, I::State, J::State)>where
T: FnMut(A, B, C, D, E, F, G, H, I, J) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>, I::Item<'a>, J::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
I: SystemParam + 'static,
J: SystemParam + 'static,
impl<T, A, B, C, D, E, F, G, H, I, J> System for FunctionSystem<T, (A, B, C, D, E, F, G, H, I, J), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State, I::State, J::State)>where
T: FnMut(A, B, C, D, E, F, G, H, I, J) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>, I::Item<'a>, J::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
I: SystemParam + 'static,
J: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F, G, H, I, J, K> System for FunctionSystem<T, (A, B, C, D, E, F, G, H, I, J, K), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State, I::State, J::State, K::State)>where
T: FnMut(A, B, C, D, E, F, G, H, I, J, K) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>, I::Item<'a>, J::Item<'a>, K::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
I: SystemParam + 'static,
J: SystemParam + 'static,
K: SystemParam + 'static,
impl<T, A, B, C, D, E, F, G, H, I, J, K> System for FunctionSystem<T, (A, B, C, D, E, F, G, H, I, J, K), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State, I::State, J::State, K::State)>where
T: FnMut(A, B, C, D, E, F, G, H, I, J, K) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>, I::Item<'a>, J::Item<'a>, K::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
I: SystemParam + 'static,
J: SystemParam + 'static,
K: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F, G, H, I, J, K, L> System for FunctionSystem<T, (A, B, C, D, E, F, G, H, I, J, K, L), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State, I::State, J::State, K::State, L::State)>where
T: FnMut(A, B, C, D, E, F, G, H, I, J, K, L) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>, I::Item<'a>, J::Item<'a>, K::Item<'a>, L::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
I: SystemParam + 'static,
J: SystemParam + 'static,
K: SystemParam + 'static,
L: SystemParam + 'static,
impl<T, A, B, C, D, E, F, G, H, I, J, K, L> System for FunctionSystem<T, (A, B, C, D, E, F, G, H, I, J, K, L), (A::State, B::State, C::State, D::State, E::State, F::State, G::State, H::State, I::State, J::State, K::State, L::State)>where
T: FnMut(A, B, C, D, E, F, G, H, I, J, K, L) + for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>, I::Item<'a>, J::Item<'a>, K::Item<'a>, L::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
I: SystemParam + 'static,
J: SystemParam + 'static,
K: SystemParam + 'static,
L: SystemParam + 'static,