pub struct GPUTextureArray { /* private fields */ }Expand description
The GPU-resident array texture an uploaded TextureArray produces.
Implementations
Sourceimpl GPUTextureArray
impl GPUTextureArray
Sourcepub fn write_layer(&self, layer: u32, mip_level: u32, pixels: &[u8])
pub fn write_layer(&self, layer: u32, mip_level: u32, pixels: &[u8])
Overwrites one mip level of one layer with new pixel data.
pub fn layer_count(&self) -> u32
pub fn width(&self) -> u32
pub fn height(&self) -> u32
Sourcepub fn get_view(&self, layer: u32, mip_level: u32) -> TextureView
pub fn get_view(&self, layer: u32, mip_level: u32) -> TextureView
A view into a single layer and mip level.