Module flags

Module flags 

Structs

BufferUsages
What a GPU buffer can be used for — passed to BufferBuilder::with_usage.
ColorWrites
Which color channels a render pipeline writes — see ColorTargetState.
DeviceFeatures
Optional GPU capabilities that can be requested when the graphics backend is initialized — see Backend::features.
ShaderStages
Which shader stages a bind group entry is visible to.
TextureUsages
What a GPU texture can be used for — passed to Texture::with_extra_usage.