Structs
- Current
Frame - Resource holding the frame acquired at the start of each render tick.
- Depth
Target - Specifies the depth attachment for a render pass.
- Pass
- Describes a render pass: a set of color attachments and an optional depth attachment to render into.
Enums
- Color
Target - Specifies a color attachment for a render pass.
Traits
- Backend
- A unified graphics backend for both native and web targets.
- Frame
Operations - Operations that can be performed on a single acquired frame.