ColorTarget

Enum ColorTarget 

pub enum ColorTarget<'a, F: FrameOperations + ?Sized> {
    Default {
        clear: Option<[f32; 4]>,
    },
    Custom {
        attachment: &'a F::Attachment,
        clear: Option<[f32; 4]>,
    },
}
Specifies a color attachment for a render pass.

Variants



Default

Use the backend’s default surface attachment.

Fields

clear: Option<[f32; 4]>

Some(color) to clear to that color, None to load existing contents.



Custom

Use a custom attachment (e.g. an off-screen texture).

Fields

attachment: &'a F::Attachment
clear: Option<[f32; 4]>

Some(color) to clear to that color, None to load existing contents.

Implementations

Source

impl<'a, F: FrameOperations> ColorTarget<'a, F>

pub fn default(clear: [f32; 4]) -> Self

Default attachment, cleared to clear.

pub fn default_load() -> Self

Default attachment, loading existing contents (no clear).

pub fn custom(attachment: &'a F::Attachment, clear: [f32; 4]) -> Self

Custom attachment, cleared to clear.

pub fn custom_load(attachment: &'a F::Attachment) -> Self

Custom attachment, loading existing contents (no clear).