FrameOperations

Trait FrameOperations 

pub trait FrameOperations:
    Sync
    + Send
    + 'static {
    type Context<'a>;
    type Attachment;
    type DepthAttachment;

    // Required method
    fn begin(&mut self, pass: Pass<'_, Self>) -> Self::Context<'_>;
}
Operations that can be performed on a single acquired frame.

Implemented by the per-frame type returned from Backend::acquire.

Required Associated Types

type Context<'a>

The render-pass context (e.g. a command encoder or render pass handle).

type Attachment

A color attachment (e.g. a texture view).

type DepthAttachment

A depth attachment (e.g. a depth-stencil texture view).

Required Methods

fn begin(&mut self, pass: Pass<'_, Self>) -> Self::Context<'_>

Begin a render pass and return the rendering context.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors