pub fn init_channel<T: 'static + Send>() -> (InitSender<T>, InitReceiver<T>)Expand description
Create a matched InitSender / InitReceiver pair for communicating a
finished backend from its init task back to the main loop.
pub fn init_channel<T: 'static + Send>() -> (InitSender<T>, InitReceiver<T>)Create a matched InitSender / InitReceiver pair for communicating a
finished backend from its init task back to the main loop.