Structs
- Window
Config - Configuration passed to a
WindowProviderwhen creating a window. - Window
Resource - Resource inserted by
WindowPluginthat gives systems access to the window handle and the exposed value.
Traits
- GPUSurface
Handle - A window handle that can be used to create a GPU surface.
- Presentable
Window - Marker trait for window providers whose handle can be used as a GPU surface.
- Window
Provider - Abstracts over a platform-specific window implementation.
- Window
Runner - A
WindowProviderthat can drive the application’s main loop.