pub struct FunctionSystem<F, Marker> {
pub func: F,
/* private fields */
}Fields
func: FTrait Implementations
Sourceimpl<T, A> System for FunctionSystem<T, (A,)>where
T: for<'a> FnMut(A::Item<'a>) + 'static,
A: SystemParam + 'static,
impl<T, A> System for FunctionSystem<T, (A,)>where
T: for<'a> FnMut(A::Item<'a>) + 'static,
A: SystemParam + 'static,
Sourceimpl<T, A, B> System for FunctionSystem<T, (A, B)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
impl<T, A, B> System for FunctionSystem<T, (A, B)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
Sourceimpl<T, A, B, C> System for FunctionSystem<T, (A, B, C)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
impl<T, A, B, C> System for FunctionSystem<T, (A, B, C)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
Sourceimpl<T, A, B, C, D> System for FunctionSystem<T, (A, B, C, D)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
impl<T, A, B, C, D> System for FunctionSystem<T, (A, B, C, D)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E> System for FunctionSystem<T, (A, B, C, D, E)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
impl<T, A, B, C, D, E> System for FunctionSystem<T, (A, B, C, D, E)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F> System for FunctionSystem<T, (A, B, C, D, E, F)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
impl<T, A, B, C, D, E, F> System for FunctionSystem<T, (A, B, C, D, E, F)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F, G> System for FunctionSystem<T, (A, B, C, D, E, F, G)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
impl<T, A, B, C, D, E, F, G> System for FunctionSystem<T, (A, B, C, D, E, F, G)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
Sourceimpl<T, A, B, C, D, E, F, G, H> System for FunctionSystem<T, (A, B, C, D, E, F, G, H)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,
impl<T, A, B, C, D, E, F, G, H> System for FunctionSystem<T, (A, B, C, D, E, F, G, H)>where
T: for<'a> FnMut(A::Item<'a>, B::Item<'a>, C::Item<'a>, D::Item<'a>, E::Item<'a>, F::Item<'a>, G::Item<'a>, H::Item<'a>) + 'static,
A: SystemParam + 'static,
B: SystemParam + 'static,
C: SystemParam + 'static,
D: SystemParam + 'static,
E: SystemParam + 'static,
F: SystemParam + 'static,
G: SystemParam + 'static,
H: SystemParam + 'static,