pub fn build_dynamic_uniform_buffer(
device: &Device,
element_size: u64,
count: u64,
) -> (Buffer, u64)Expand description
Builds an empty buffer sized to hold count elements of a dynamically-offset uniform
buffer, and returns the buffer along with the per-element stride to use as dynamic
offsets in RenderPass::set_bind_group.