update_buffer_at

Function update_buffer_at 

pub fn update_buffer_at(
    queue: &Queue,
    buffer: &Buffer,
    offset: u64,
    data: &[u8],
)
Writes data into buffer at a byte offset, for updating one element of a dynamically-offset buffer without touching the others. offset should be a multiple of the stride returned by [dynamic_offset_stride].