pub struct Cubemap { /* private fields */ }Expand description
Source data for GPUCubemap. Fields are private — build one via the
from_files/from_faces/
empty constructors rather than as a struct literal.
Implementations
Sourceimpl Cubemap
impl Cubemap
Sourcepub fn from_files(size: u32, files: [&'static str; 6]) -> Self
pub fn from_files(size: u32, files: [&'static str; 6]) -> Self
Load 6 faces from files (+X, -X, +Y, -Y, +Z, -Z). Size is inferred from the first face.
Sourcepub fn from_faces(size: u32, format: TextureFormat, faces: [Vec<u8>; 6]) -> Self
pub fn from_faces(size: u32, format: TextureFormat, faces: [Vec<u8>; 6]) -> Self
Supply raw pixel bytes for each face (+X, -X, +Y, -Y, +Z, -Z).
Sourcepub fn empty(size: u32, format: TextureFormat) -> Self
pub fn empty(size: u32, format: TextureFormat) -> Self
Allocate an empty cubemap for use as a render target (e.g. environment capture).
Sourcepub fn with_format(self, format: TextureFormat) -> Self
pub fn with_format(self, format: TextureFormat) -> Self
Override the format set by whichever constructor was used (all
three default to or take format directly — this exists for the
builder-chain case, e.g. Cubemap::empty(size, format).with_mips()
followed later by a format change, without re-specifying size).
Sourcepub fn build_asset(self, name: &str, assets: &mut Assets<Self>) -> Handle<Self>
pub fn build_asset(self, name: &str, assets: &mut Assets<Self>) -> Handle<Self>
Consume the builder, insert into assets under name, and return
the resulting Handle<Cubemap>.