pub struct BufferUsages(/* private fields */);Expand description
Allowed usages of a buffer — mirrors wgpu::BufferUsages bit-for-bit.
Implementations
Sourceimpl BufferUsages
impl BufferUsages
pub const MAP_READ: Self
pub const MAP_WRITE: Self
pub const COPY_SRC: Self
pub const COPY_DST: Self
pub const INDEX: Self
pub const VERTEX: Self
pub const UNIFORM: Self
pub const STORAGE: Self
pub const INDIRECT: Self
pub const QUERY_RESOLVE: Self
Sourcepub const BLAS_INPUT: Self
pub const BLAS_INPUT: Self
Allows a buffer to be used as input for a bottom level acceleration structure build.
Sourcepub const TLAS_INPUT: Self
pub const TLAS_INPUT: Self
Allows a buffer to be used as input for a top level acceleration structure build.
pub const fn bits(self) -> u32
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Whether every flag set in other is also set in self.
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Whether self and other share any set flag.