pub struct TextureUsages(/* private fields */);Expand description
Allowed usages of a texture — mirrors wgpu::TextureUsages bit-for-bit.
Implementations
Sourceimpl TextureUsages
impl TextureUsages
pub const COPY_SRC: Self
pub const COPY_DST: Self
pub const TEXTURE_BINDING: Self
pub const STORAGE_BINDING: Self
pub const RENDER_ATTACHMENT: Self
Sourcepub const STORAGE_ATOMIC: Self
pub const STORAGE_ATOMIC: Self
Allows a texture to be used with image atomics. Requires a native-only feature.
pub const fn bits(self) -> u32
Sourcepub const fn contains(self, other: Self) -> bool
pub const fn contains(self, other: Self) -> bool
Whether every flag set in other is also set in self.
Sourcepub const fn intersects(self, other: Self) -> bool
pub const fn intersects(self, other: Self) -> bool
Whether self and other share any set flag.