pub enum MaterialBindingKind {
Texture {
sample_type: TextureSampleType,
view_dimension: TextureViewDimension,
multisampled: bool,
},
Sampler,
ComparisonSampler,
UniformBuffer {
visibility: ShaderStages,
has_dynamic_offset: bool,
min_binding_size: Option<BufferSize>,
},
StorageBufferReadOnly {
visibility: ShaderStages,
has_dynamic_offset: bool,
min_binding_size: Option<BufferSize>,
},
StorageBufferReadWrite {
visibility: ShaderStages,
has_dynamic_offset: bool,
min_binding_size: Option<BufferSize>,
},
}Variants
Implementations
Sourceimpl MaterialBindingKind
impl MaterialBindingKind
pub fn texture_2d() -> Self
pub fn texture_2d_array() -> Self
pub fn texture_cubemap() -> Self
pub fn uniform_buffer() -> Self
Sourcepub fn dynamic_uniform_buffer(element_size: u64) -> Self
pub fn dynamic_uniform_buffer(element_size: u64) -> Self
A uniform buffer bound with a per-draw dynamic offset, e.g. one large buffer
holding many objects’ data, rebound at a different offset via
RenderPass::set_bind_group’s dynamic offsets slice instead of a bind group per object.
element_size is the size in bytes of a single element (before alignment padding);
use crate::wgpu::buffers::dynamic_uniform_offset_stride or
crate::wgpu::buffers::build_dynamic_uniform_buffer to compute the actual stride.
Sourcepub fn dynamic_storage_buffer(element_size: u64, read_only: bool) -> Self
pub fn dynamic_storage_buffer(element_size: u64, read_only: bool) -> Self
A storage buffer bound with a per-draw dynamic offset. See Self::dynamic_uniform_buffer.
pub fn layout_entry(&self, binding: u32) -> BindGroupLayoutEntry