pub struct SystemConfig<S, Params> { /* private fields */ }Expand description
A system bundled with .after(...)/.before(...) ordering constraints,
produced by IntoSystemConfig::after/IntoSystemConfig::before and
consumed by Schedule::add_system.
Implementations
Sourceimpl<S, Params> SystemConfig<S, Params>where
S: IntoSystem<Params> + 'static,
impl<S, Params> SystemConfig<S, Params>where
S: IntoSystem<Params> + 'static,
Sourcepub fn after<S2, P2>(self, _other: S2) -> Selfwhere
S2: IntoSystem<P2> + 'static,
pub fn after<S2, P2>(self, _other: S2) -> Selfwhere
S2: IntoSystem<P2> + 'static,
Adds a constraint that this system must run after other. other
need not be added to the schedule yet — only its type is used, to
look it up when the schedule’s order is next computed.
Sourcepub fn before<S2, P2>(self, _other: S2) -> Selfwhere
S2: IntoSystem<P2> + 'static,
pub fn before<S2, P2>(self, _other: S2) -> Selfwhere
S2: IntoSystem<P2> + 'static,
Adds a constraint that this system must run before other. other
need not be added to the schedule yet — only its type is used, to
look it up when the schedule’s order is next computed.