Structs
- Color
Target - One color attachment for a
Pass.attachment: Nonemeans “the swapchain’s own view” — pass aTextureViewto render into your own texture instead (e.g. for post-processing). - Color
Target Builder - Depth
Target - A depth attachment for a
Pass— unlike a color target, always pointed at your own texture (there’s no swapchain depth buffer). - Depth
Target Builder - Pass
- What to render into, passed to
Frame::begin. Zero color targets plus a depth target is a valid, depth-only pass (e.g. a shadow map). - Pass
Builder