Structs
- Buffer
Usages - What a GPU buffer can be used for — passed to
BufferBuilder::with_usage. - Color
Writes - Which color channels a render pipeline writes — see
ColorTargetState. - Device
Features - Optional GPU capabilities that can be requested when the graphics backend is
initialized — see
Backend::features. - Shader
Stages - Which shader stages a bind group entry is visible to.
- Texture
Usages - What a GPU texture can be used for — passed to
RenderTargetTextureBuilder::with_usage.