Skip to main contentModule backend
Source - CurrentFrame
- Resource holding the frame acquired at the start of each render tick.
- DepthTarget
- Specifies the depth attachment for a render pass.
- Pass
- Describes a render pass: a set of color attachments and an optional depth
attachment to render into.
- ColorTarget
- Specifies a color attachment for a render pass.
- Backend
- A unified graphics backend for both native and web targets.
- Bindable
- Implement for types that can bind themselves (e.g. pipelines, bind groups)
into a render context.
- Drawable
- Implement for types that can issue draw commands into a render context.
- FrameOperations
- Operations that can be performed on a single acquired frame.