Module window

Module window 

Structs

WindowConfig
Configuration passed to a WindowProvider when creating a window.
WindowResource
Resource inserted by WindowPlugin that gives systems access to the window handle and the exposed value.

Traits

GPUSurfaceHandle
A window handle that can be used to create a GPU surface.
PresentableWindow
Marker trait for window providers whose handle can be used as a GPU surface.
WindowProvider
Abstracts over a platform-specific window implementation.
WindowRunner
A WindowProvider that can drive the application’s main loop.