Module layout

Module layout 

Structs

GroupLayout
A bind group layout tagged with the @group(N) it occupies in the pipeline.
OwnedGroupLayout
An owned bind group layout tagged with the @group(N) it occupies, for descriptors that hold layouts by value.